@@ -4,21 +4,19 @@
 #'   confidence interval whiskers and other statistical details included as
 #'   labels.
 #'
-#' @param x A model object to be tidied, or a tidy data frame containing
-#'   results. If a data frame is to be plotted, it *must* contain columns named
-#'   `term` (names of predictors), or `estimate` (corresponding estimates of
-#'   coefficients or other quantities of interest). Other optional columns are
-#'   `conf.low` and `conf.high` (for confidence intervals); `p.value`. It is
-#'   important that all `term` names should be unique. Function internally uses
-#'   `broom::tidy` or `parameters::model_parameters` to get a tidy dataframe.
+#' @param x A model object to be tidied, or a tidy data frame containing results
+#'   from a regression model. Function internally uses
+#'   `parameters::model_parameters` or `broom::tidy` to get a tidy dataframe. If
+#'   a data frame is used, it *must* contain columns named `term` (names of
+#'   predictors) and `estimate` (corresponding estimates of coefficients or
+#'   other quantities of interest).
 #' @param output Character describing the expected output from this function:
 #'   `"plot"` (visualization of regression coefficients) or `"tidy"` (tidy
 #'   dataframe of results from `broom::tidy`) or `"glance"` (object from
 #'   `broom::glance`) or `"augment"` (object from `broom::augment`).
 #' @param statistic Which statistic is to be displayed (either `"t"` or `"f"`or
-#'   `"z"`) in the label. This is especially important if the `x` argument in
-#'   `ggcoefstats` is a dataframe in which case the function wouldn't know what
-#'   kind of model it is dealing with.
+#'   `"z"` or `"chi"`) in the label. This is relevant if the `x` argument is a
+#'   *dataframe*.
 #' @param bf.message Logical that decides whether results from running a
 #'   Bayesian meta-analysis assuming that the effect size *d* varies across
 #'   studies with standard deviation *t* (i.e., a random-effects analysis)
@@ -41,8 +39,6 @@
 #' @param partial Logical that decides if partial eta-squared or partial
 #'   omega-squared are returned (Default: `TRUE`). If `FALSE`, eta-squared or
 #'   omega-squared will be returned.
-#' @param nboot Number of bootstrap samples for confidence intervals for partial
-#'   eta-squared and omega-squared (Default: `500L`).
 #' @param meta.analytic.effect Logical that decides whether subtitle for
 #'   meta-analysis via linear (mixed-effects) models (default: `FALSE`). If
 #'   `TRUE`, input to argument `subtitle` will be ignored. This will be mostly
@@ -52,8 +48,6 @@
 #'   meta-analysis. If `"parametric"` (default), `metafor::rma` function will be
 #'   used. If `"robust"`, `metaplus::metaplus` function will be used. If
 #'   `"bayes"`, `metaBMA::meta_random` function will be used.
-#' @param k Number of decimal places expected for results displayed in labels
-#'   (Default : `k = 2`).
 #' @param exclude.intercept Logical that decides whether the intercept should be
 #'   excluded from the plot (Default: `TRUE`).
 #' @param exponentiate If `TRUE`, the `x`-axis will be logarithmic (Default:
@@ -75,9 +69,9 @@
 #' @param stats.labels Logical. Decides whether the statistic and *p*-values for
 #'   each coefficient are to be attached to each dot as a text label using
 #'   `ggrepel` (Default: `TRUE`).
-#' @param stats.label.color Color for the labels. If `stats.label.color` is
-#'   `NULL`, colors will be chosen from the specified `package` (Default:
-#'   `"RColorBrewer"`) and `palette` (Default: `"Dark2"`).
+#' @param stats.label.color Color for the labels. If set to `NULL`, colors will
+#'   be chosen from the specified `package` (Default: `"RColorBrewer"`) and
+#'   `palette` (Default: `"Dark2"`).
 #' @param stats.label.args Additional arguments that will be passed to
 #'   `ggrepel::geom_label_repel` geom. Please see documentation for that
 #'   function to know more about these arguments.
@@ -85,14 +79,10 @@
 #'   is shown (Default: `FALSE`). This can be helpful when a large number of
 #'   regression coefficients are to be displayed in a single plot. Relevant only
 #'   when the `output` is a plot.
-#' @param caption.summary Logical that decides whether the model summary should
-#'   be displayed as a cation to the plot (Default: `TRUE`). Color of the line
-#'   segment. Defaults to the same color as the text.
-#' @param ... Additional arguments to tidying method.
+#' @param ... Additional arguments to tidying method. For more, see
+#'   `?parameters::model_parameters` and `broom::tidy`.
 #' @inheritParams statsExpressions::bf_meta
 #' @inheritParams parameters::model_parameters
-#' @inheritParams broom::tidy.clm
-#' @inheritParams broom::tidy.polr
 #' @inheritParams theme_ggstatsplot
 #' @inheritParams statsExpressions::expr_meta_parametric
 #' @inheritParams ggbetweenstats
@@ -100,19 +90,20 @@
 #' @import ggplot2
 #' @importFrom rlang exec !!!
 #' @importFrom broomExtra tidy glance augment
-#' @importFrom dplyr select bind_rows summarize mutate mutate_at mutate_if n
-#' @importFrom dplyr group_by arrange full_join vars matches desc everything
-#' @importFrom dplyr vars all_vars filter_at starts_with row_number
-#' @importFrom stats as.formula lm confint qnorm p.adjust
+#' @importFrom dplyr select mutate matches vars all_vars filter_at row_number
+#' @importFrom stats qnorm lm
 #' @importFrom ggrepel geom_label_repel
 #' @importFrom tidyr unite
-#' @importFrom groupedstats lm_effsize_standardizer
 #' @importFrom insight is_model
 #' @importFrom statsExpressions expr_meta_parametric bf_meta
 #'
 #' @references
 #' \url{https://indrajeetpatil.github.io/ggstatsplot/articles/web_only/ggcoefstats.html}
 #'
+#' @note All rows of regression estimates where either of the following
+#'   quantities is `NA` will be removed if labels are requested: `estimate`,
+#'   `statistic`, `p.value`.
+#'
 #' @examples
 #' \donttest{
 #' # for reproducibility
@@ -210,18 +201,6 @@
 #'   meta.analytic.effect = TRUE,
 #'   k = 3
 #' )
-#'
-#' # -------------- getting model summary ------------------------------
-#'
-#' # model
-#' library(lme4)
-#' lmm1 <- lme4::lmer(
-#'   formula = Reaction ~ Days + (Days | Subject),
-#'   data = sleepstudy
-#' )
-#'
-#' # dataframe with model summary
-#' ggstatsplot::ggcoefstats(x = lmm1, output = "glance")
 #' }
 #' @export
 
@@ -229,25 +208,23 @@
 ggcoefstats <- function(x,
                         output = "plot",
                         statistic = NULL,
-                        bf.message = TRUE,
-                        effsize = "eta",
-                        partial = TRUE,
-                        nboot = 500L,
-                        meta.analytic.effect = FALSE,
-                        meta.type = "parametric",
                         conf.int = TRUE,
                         conf.level = 0.95,
-                        k = 2,
+                        k = 2L,
                         exclude.intercept = TRUE,
                         exponentiate = FALSE,
+                        effsize = "eta",
+                        partial = TRUE,
+                        meta.analytic.effect = FALSE,
+                        meta.type = "parametric",
+                        bf.message = TRUE,
                         sort = "none",
                         xlab = "regression coefficient",
                         ylab = "term",
                         title = NULL,
                         subtitle = NULL,
-                        only.significant = FALSE,
                         caption = NULL,
-                        caption.summary = TRUE,
+                        only.significant = FALSE,
                         point.args = list(size = 3, color = "blue"),
                         errorbar.args = list(height = 0),
                         vline = TRUE,
@@ -259,33 +236,8 @@ ggcoefstats <- function(x,
                         palette = "Dark2",
                         ggtheme = ggplot2::theme_bw(),
                         ggstatsplot.layer = TRUE,
-                        messages = FALSE,
                         ...) {
 
-  # =================== list of objects (for tidy and glance) ================
-
-  # models for which statistic is F-value
-  f.mods <- c("aov", "aovlist", "anova", "Gam", "manova")
-
-  # ============================= model summary ============================
-
-  # creating glance dataframe
-  glance_df <- broomExtra::glance_performance(x)
-
-  # if glance is not available, inform the user
-  if (isTRUE(insight::is_model(x))) {
-    if (is.null(glance_df) || !all(c("aic", "bic") %in% names(glance_df))) {
-      # inform the user
-      message(cat(
-        ipmisc::green("Note:"),
-        ipmisc::blue("AIC and BIC values not available, so skipping caption.\n")
-      ))
-
-      # and skip the caption
-      caption.summary <- FALSE
-    }
-  }
-
   # ============================= dataframe ===============================
 
   if (isFALSE(insight::is_model(x))) {
@@ -312,10 +264,10 @@ ggcoefstats <- function(x,
   # =========================== broom.mixed tidiers =======================
 
   if (isTRUE(insight::is_model(x))) {
-    if (class(x)[[1]] %in% f.mods) {
+    if (class(x)[[1]] %in% c("aov", "aovlist", "anova", "Gam", "manova")) {
       # creating dataframe
       tidy_df <-
-        groupedstats::lm_effsize_standardizer(
+        lm_effsize_standardizer(
           object = x,
           effsize = effsize,
           partial = partial,
@@ -363,6 +315,16 @@ ggcoefstats <- function(x,
     )
   }
 
+  # remove NAs
+  if (isTRUE(stats.labels)) {
+    tidy_df %<>%
+      dplyr::filter_at(
+        .tbl = .,
+        .vars = dplyr::vars(dplyr::matches("estimate|statistic|std.error|p.value")),
+        .vars_predicate = dplyr::all_vars(!is.na(.))
+      )
+  }
+
   # create a new term column if it's not present
   if (!"term" %in% names(tidy_df)) {
     tidy_df %<>%
@@ -370,7 +332,7 @@ ggcoefstats <- function(x,
       dplyr::mutate(.data = ., term = paste("term", term, sep = "_"))
   }
 
-  # =================== check for duplicate terms ============================
+  # ================ check for duplicate terms and columns ===================
 
   # a check if there are repeated terms
   if (any(duplicated(dplyr::select(tidy_df, term)))) {
@@ -388,30 +350,14 @@ ggcoefstats <- function(x,
   if (any(duplicated(dplyr::select(tidy_df, term)))) {
     message(cat(
       ipmisc::red("Error: "),
-      ipmisc::blue("All elements in the column `term` should be unique.\n"),
+      ipmisc::blue("All elements in the column `term` should be unique."),
       sep = ""
     ))
     return(invisible(tidy_df))
   }
 
-  # ================== statistic and p-value check ===========================
-
   # if broom output doesn't contain p-value or statistic column
-  if (sum(c("p.value", "statistic") %in% names(tidy_df)) != 2) {
-    # skip the labels
-    stats.labels <- FALSE
-
-    # inform the user that skipping labels for the same reason
-    # (relevant only in case of a plot)
-    if (output == "plot") {
-      message(cat(
-        ipmisc::green("Note: "),
-        ipmisc::blue("No p-values and/or statistic available for the model object;"),
-        ipmisc::blue("\nskipping labels with statistical details.\n"),
-        sep = ""
-      ))
-    }
-  }
+  if (sum(c("p.value", "statistic") %in% names(tidy_df)) != 2L) stats.labels <- FALSE
 
   # ==================== confidence intervals check ===========================
 
@@ -432,8 +378,7 @@ ggcoefstats <- function(x,
         )
     } else {
       # add NAs so that only dots will be shown
-      tidy_df %<>%
-        dplyr::mutate(.data = ., conf.low = NA_character_, conf.high = NA_character_)
+      tidy_df %<>% dplyr::mutate(conf.low = NA_character_, conf.high = NA_character_)
 
       # stop displaying whiskers
       conf.int <- FALSE
@@ -441,8 +386,8 @@ ggcoefstats <- function(x,
       # inform the user that skipping labels for the same reason
       message(cat(
         ipmisc::green("Note: "),
-        ipmisc::blue("No confidence intervals available for regression coefficients"),
-        ipmisc::blue("object, so skipping whiskers in the plot.\n"),
+        ipmisc::blue("No confidence intervals available for regression coefficients,"),
+        ipmisc::blue("so whiskers in the plot will be skipped.\n"),
         sep = ""
       ))
     }
@@ -450,24 +395,10 @@ ggcoefstats <- function(x,
 
   # ============= intercept, exponentiation, and final tidy dataframe =========
 
-  # ordering the dataframe
-  tidy_df %<>%
-    dplyr::select(
-      .data = .,
-      term,
-      estimate,
-      conf.low,
-      conf.high,
-      dplyr::everything()
-    )
-
   # whether to show model intercept
   # if not, remove the corresponding terms from the dataframe
   if (isTRUE(exclude.intercept)) {
-    tidy_df %<>%
-      dplyr::filter(
-        .data = ., !grepl(pattern = "(Intercept)", x = term, ignore.case = TRUE)
-      )
+    tidy_df %<>% dplyr::filter(!grepl(pattern = "(Intercept)", x = term, ignore.case = TRUE))
   }
 
   # ========================== preparing label ================================
@@ -488,74 +419,16 @@ ggcoefstats <- function(x,
       )
   }
 
-  # ============== meta-analysis plus Bayes factor =========================
-
-  # check if meta-analysis is to be run
-  if (isTRUE(meta.analytic.effect) && "std.error" %in% names(tidy_df)) {
-    if (dim(dplyr::filter(.data = tidy_df, is.na(std.error)))[[1]] > 0L) {
-      # inform the user that skipping labels for the same reason
-      message(cat(
-        ipmisc::red("Error: "),
-        ipmisc::blue("At least one of the `std.error` column values is `NA`.\n"),
-        ipmisc::blue("No meta-analysis will be carried out.\n"),
-        sep = ""
-      ))
-
-      # turn off meta-analysis
-      meta.analytic.effect <- FALSE
-    }
-  }
-
-  # running meta-analysis
-  if (isTRUE(meta.analytic.effect)) {
-    # standardizing type of statistics name
-    meta.type <- stats_type_switch(meta.type)
-
-    # results from frequentist random-effects meta-analysis
-    subtitle <-
-      subtitle_function_switch(
-        test = "meta",
-        type = meta.type,
-        data = tidy_df,
-        k = k
-      )
-
-    # results from Bayesian random-effects meta-analysis
-    if (isTRUE(bf.message) && meta.type == "parametric") {
-      caption <-
-        statsExpressions::bf_meta(
-          caption = caption,
-          output = "caption",
-          data = tidy_df,
-          k = k
-        )
-    }
-
-    # model summary (detailed only for parametric statistics)
-    if (meta.type == "parametric") {
-      caption.meta <-
-        statsExpressions::expr_meta_parametric(
-          data = tidy_df,
-          k = k,
-          caption = caption,
-          output = "caption"
-        )
-    } else {
-      caption.meta <- caption
-    }
-  }
-
   # ========================== summary caption ================================
 
-  # caption containing model diagnostics
-  if (isTRUE(caption.summary)) {
-    # for dataframe objects
-    if (isFALSE(insight::is_model(x)) && isTRUE(meta.analytic.effect)) {
-      caption <- caption.meta
-    }
+  # for non-dataframe objects
+  if (isTRUE(insight::is_model(x))) {
+    # creating glance dataframe
+    glance_df <- broomExtra::glance_performance(x)
+    meta.analytic.effect <- FALSE
 
-    # for non-dataframe objects
-    if (isTRUE(insight::is_model(x))) {
+    # if glance is not available, inform the user
+    if (!is.null(glance_df) && all(c("aic", "bic") %in% names(glance_df))) {
       # preparing caption with model diagnostics
       caption <-
         substitute(
@@ -572,6 +445,44 @@ ggcoefstats <- function(x,
     }
   }
 
+  # running meta-analysis
+  if (isTRUE(meta.analytic.effect)) {
+    # standardizing type of statistics name
+    meta.type <- ipmisc::stats_type_switch(meta.type)
+
+    # results from frequentist random-effects meta-analysis
+    subtitle <-
+      subtitle_function_switch(
+        test = "meta",
+        type = meta.type,
+        data = tidy_df,
+        k = k
+      )
+
+    # model summary (detailed only for parametric statistics)
+    if (meta.type == "parametric") {
+      # results from Bayesian random-effects meta-analysis
+      if (isTRUE(bf.message)) {
+        caption <-
+          statsExpressions::bf_meta(
+            caption = caption,
+            output = "caption",
+            data = tidy_df,
+            k = k
+          )
+      }
+
+      # caption with heterogeneity test results
+      caption <-
+        statsExpressions::expr_meta_parametric(
+          data = tidy_df,
+          k = k,
+          caption = caption,
+          output = "caption"
+        )
+    }
+  }
+
   # ========================== sorting ===================================
 
   # whether the term need to be arranged in any specified order
@@ -600,19 +511,15 @@ ggcoefstats <- function(x,
   # palette check is necessary only if output is a plot
   if (output == "plot") {
     # setting up the basic architecture
-    plot <-
-      ggplot2::ggplot(data = tidy_df, mapping = ggplot2::aes(x = estimate, y = term))
+    plot <- ggplot2::ggplot(data = tidy_df, mapping = ggplot2::aes(x = estimate, y = term))
 
     # if needed, adding the vertical line
     if (isTRUE(vline)) {
-      # either at 1 - if coefficients are to be exponentiated - or at 0
-      xintercept <- ifelse(exponentiate, 1, 0)
-
       # adding the line geom
       plot <- plot +
         rlang::exec(
           .fn = ggplot2::geom_vline,
-          xintercept = xintercept,
+          xintercept = ifelse(exponentiate, 1, 0),
           na.rm = TRUE,
           !!!vline.args
         )
@@ -645,14 +552,6 @@ ggcoefstats <- function(x,
 
     # adding the labels
     if (isTRUE(stats.labels)) {
-      # removing all rows that have NAs anywhere in the columns of interest
-      tidy_df %<>%
-        dplyr::filter_at(
-          .tbl = .,
-          .vars = dplyr::vars(dplyr::matches("estimate|statistic|std.error|p.value")),
-          .vars_predicate = dplyr::all_vars(!is.na(.))
-        )
-
       # only significant p-value labels are shown
       if (isTRUE(only.significant) && "significance" %in% names(tidy_df)) {
         tidy_df %<>%
