@@ -18,6 +18,9 @@
 #'   (default), `"counts"`, `"both"`.
 #' @param label.args Additional aesthetic arguments that will be passed to
 #'   `geom_label`.
+#' @param label.repel Whether labels should be repelled using `ggrepel` package.
+#'   This can be helpful in case the labels are overlapping.
+#' @param legend.title Title text for the legend.
 #' @inheritParams ggbetweenstats
 #' @inheritParams tidyBF::bf_contingency_tab
 #' @inheritParams statsExpressions::expr_contingency_tab
@@ -32,8 +35,8 @@
 #'
 #' @importFrom dplyr select mutate vars pull
 #' @importFrom rlang !! enquo quo_name as_name ensym
+#' @importFrom ggrepel geom_label_repel
 #' @importFrom paletteer scale_fill_paletteer_d
-#' @importFrom groupedstats grouped_proptest
 #' @importFrom tidyr uncount drop_na
 #' @importFrom statsExpressions bf_contingency_tab expr_contingency_tab
 #'
@@ -64,7 +67,6 @@
 #'   data = mtcars,
 #'   x = vs,
 #'   y = cyl,
-#'   nboot = 10,
 #'   legend.title = "Engine"
 #' )
 #' @export
@@ -78,8 +80,13 @@ ggpiestats <- function(data,
                        paired = FALSE,
                        results.subtitle = TRUE,
                        label = "percentage",
+                       label.args = list(direction = "both"),
+                       label.repel = FALSE,
+                       conf.level = 0.95,
+                       nboot = 100L,
+                       k = 2L,
+                       proportion.test = TRUE,
                        perc.k = 0,
-                       label.args = list(alpha = 1, fill = "white"),
                        bf.message = TRUE,
                        sampling.plan = "indepMulti",
                        fixed.margin = "rows",
@@ -87,18 +94,13 @@ ggpiestats <- function(data,
                        title = NULL,
                        subtitle = NULL,
                        caption = NULL,
-                       conf.level = 0.95,
-                       nboot = 100,
                        legend.title = NULL,
-                       k = 2,
-                       proportion.test = TRUE,
                        ggtheme = ggplot2::theme_bw(),
                        ggstatsplot.layer = TRUE,
                        package = "RColorBrewer",
                        palette = "Dark2",
                        ggplot.component = NULL,
                        output = "plot",
-                       messages = TRUE,
                        x = NULL,
                        y = NULL,
                        ...) {
@@ -112,8 +114,6 @@ ggpiestats <- function(data,
   y <- y %||% condition
   counts <- if (!rlang::quo_is_null(rlang::enquo(counts))) rlang::ensym(counts)
 
-  # ================= extracting column names as labels  =====================
-
   # saving the column label for the 'x' variables
   if (rlang::is_null(legend.title)) legend.title <- rlang::as_name(x)
 
@@ -168,8 +168,7 @@ ggpiestats <- function(data,
           conf.level = conf.level,
           conf.type = "norm",
           bias.correct = TRUE,
-          k = k,
-          messages = messages
+          k = k
         ),
         error = function(e) NULL
       )
@@ -191,8 +190,7 @@ ggpiestats <- function(data,
     }
   }
 
-  # convert the data into percentages; group by yal variable if needed
-  # dataframe with summary labels
+  # convert the data into percentages and add labels
   df <-
     cat_label_df(
       data = cat_counter(data = data, x = {{ x }}, y = {{ y }}),
@@ -237,22 +235,34 @@ ggpiestats <- function(data,
 
   # creating the basic plot
   p <-
-    ggplot2::ggplot(data = df, mapping = ggplot2::aes(x = "", y = counts)) +
+    ggplot2::ggplot(data = df, mapping = ggplot2::aes(x = "", y = perc)) +
     ggplot2::geom_col(
+      mapping = ggplot2::aes(fill = {{ x }}),
       position = "fill",
       color = "black",
       width = 1,
-      ggplot2::aes(fill = {{ x }}),
       na.rm = TRUE
-    ) +
+    )
+
+  # whether labels need to be repelled
+  if (isTRUE(label.repel)) {
+    .fn <- ggrepel::geom_label_repel
+  } else {
+    .fn <- ggplot2::geom_label
+  }
+
+  # adding label with percentages and/or counts
+  suppressWarnings(suppressMessages(p <- p +
     rlang::exec(
-      .fn = ggplot2::geom_label,
+      .fn = .fn,
       mapping = ggplot2::aes(label = label, group = {{ x }}),
       position = ggplot2::position_fill(vjust = 0.5),
-      show.legend = FALSE,
+      min.segment.length = 0,
+      fill = "white",
+      alpha = 1,
       na.rm = TRUE,
       !!!label.args
-    )
+    )))
 
   # if facet_wrap *is* happening
   if (!rlang::quo_is_null(rlang::enquo(y))) {
@@ -263,42 +273,30 @@ ggpiestats <- function(data,
   p <- p +
     ggplot2::coord_polar(theta = "y") +
     ggplot2::scale_y_continuous(breaks = NULL) +
-    paletteer::scale_fill_paletteer_d(
-      palette = paste0(package, "::", palette),
-      name = ""
-    ) +
-    theme_pie(
-      ggtheme = ggtheme,
-      ggstatsplot.layer = ggstatsplot.layer
-    ) + # remove black diagonal line from legend
+    paletteer::scale_fill_paletteer_d(palette = paste0(package, "::", palette), name = "") +
+    theme_pie(ggtheme = ggtheme, ggstatsplot.layer = ggstatsplot.layer) +
     ggplot2::guides(fill = ggplot2::guide_legend(override.aes = list(color = NA)))
 
-  # ================ sample size and proportion test labels =================
+  # ================ sample size + proportion test labels =================
 
-  # if faceting by y is happening
-  if (!rlang::quo_is_null(rlang::enquo(y))) {
-    # adding significance labels to pie charts for grouped proportion tests
-    if (isTRUE(proportion.test)) {
-      # display grouped proportion test results
-      if (isTRUE(messages)) print(dplyr::select(df_labels, -label))
-
-      # adding labels
-      p <- p +
-        ggplot2::geom_text(
-          data = df_labels,
-          mapping = ggplot2::aes(label = label, x = 1.65, y = 0.5),
-          position = ggplot2::position_fill(vjust = 1),
-          size = 2.8,
-          na.rm = TRUE,
-          parse = TRUE
-        )
-    }
+  # adding labels with proportion tests
+  if (!rlang::quo_is_null(rlang::enquo(y)) && isTRUE(proportion.test)) {
+    p <- p +
+      rlang::exec(
+        .fn = ggplot2::geom_text,
+        data = df_labels,
+        mapping = ggplot2::aes(label = label, x = 1.65, y = 0.5),
+        position = ggplot2::position_fill(vjust = 1),
+        size = 2.8,
+        na.rm = TRUE,
+        parse = TRUE
+      )
   }
 
   # =========================== putting all together ========================
 
   # preparing the plot
-  p <- p +
+  p +
     ggplot2::labs(
       x = NULL,
       y = NULL,
@@ -308,7 +306,4 @@ ggpiestats <- function(data,
     ) +
     ggplot2::guides(fill = ggplot2::guide_legend(title = legend.title)) +
     ggplot.component
-
-  # return the final plot
-  return(p)
 }
