@@ -63,7 +63,12 @@
 #' \url{https://indrajeetpatil.github.io/ggstatsplot/articles/web_only/ggscatterstats.html}
 #'
 #' @note
-#' The plot uses `ggrepel::geom_label_repel` to attempt to keep labels
+#' - If you set `marginal = TRUE`, the resulting plot can't be further modified
+#' with `ggplot2` functions since it is no longer a `ggplot` object. In case you
+#' want a `ggplot` object, set `marginal = FALSE`. Also have a look at the
+#' `ggplot.component` argument.
+#'
+#' - The plot uses `ggrepel::geom_label_repel` to attempt to keep labels
 #' from over-lapping to the largest degree possible.  As a consequence plot
 #' times will slow down massively (and the plot file will grow in size) if you
 #' have a lot of labels that overlap.
@@ -126,14 +131,12 @@ ggscatterstats <- function(data,
                            title = NULL,
                            subtitle = NULL,
                            caption = NULL,
-                           nboot = 100,
                            beta = 0.1,
-                           k = 2,
+                           k = 2L,
                            ggtheme = ggplot2::theme_bw(),
                            ggstatsplot.layer = TRUE,
                            ggplot.component = NULL,
                            output = "plot",
-                           messages = TRUE,
                            ...) {
 
   # convert entered stats type to a standard notation
@@ -209,13 +212,10 @@ ggscatterstats <- function(data,
         data = data,
         x = {{ x }},
         y = {{ y }},
-        nboot = nboot,
         beta = beta,
         type = type,
         conf.level = conf.level,
-        conf.type = "norm",
-        k = k,
-        messages = messages
+        k = k
       )
   }
 
@@ -418,18 +418,6 @@ ggscatterstats <- function(data,
       )
   }
 
-  #------------------------- messages  ------------------------------------
-
-  # display warning that this function doesn't produce a `ggplot2` object
-  if (isTRUE(marginal) && isTRUE(messages)) {
-    message(cat(
-      ipmisc::red("Warning: "),
-      ipmisc::blue("This plot can't be further modified with `ggplot2` functions.\n"),
-      ipmisc::blue("In case you want a `ggplot` object, set `marginal = FALSE`."),
-      sep = ""
-    ))
-  }
-
   # return the final plot
   return(plot)
 }
