@@ -54,6 +54,10 @@ ipmisc::`%|%`
 #' @importFrom ipmisc tibble
 ipmisc::tibble
 
+#' @export
+#' @importFrom ipmisc enframe
+ipmisc::enframe
+
 #' @export
 #' @importFrom ipmisc as_tibble
 ipmisc::as_tibble
