@@ -77,12 +77,22 @@ testthat::test_that(
       ggplot2::expr(atop(
         displaystyle("Studies carried out in 1887"),
         expr = paste(
-          "In favor of null: ",
           "log"["e"],
           "(BF"["01"],
           ") = ",
           "-1.2779",
           ", ",
+          widehat(italic(d))["median"]^
+            "posterior",
+          " = ",
+          "2067.9739",
+          ", CI"["95%"]^"HDI",
+          " [",
+          "228.0673",
+          ", ",
+          "13002.3127",
+          "]",
+          ", ",
           italic("r")["Cauchy"]^"JZS",
           " = ",
           "0.8800"
@@ -165,7 +175,7 @@ testthat::test_that(
           y = c(1, 2, 3, 4, 5),
           x = c(820.5, 831.5, 845, 856, 909),
           PANEL = structure(c(1L, 1L, 1L, 1L, 1L), class = "factor", .Label = "1"),
-          group = c(-1L, -1L, -1L, -1L, -1L),
+          group = structure(c(-1L, -1L, -1L, -1L, -1L), n = 1L),
           shape = c(16, 16, 16, 16, 16),
           colour = c("black", "black", "black", "black", "black"),
           size = c(3, 3, 3, 3, 3),
@@ -184,7 +194,7 @@ testthat::test_that(
         list(
           xintercept = 800,
           PANEL = structure(1L, .Label = "1", class = "factor"),
-          group = -1L,
+          group = structure(c(-1L), n = 1L),
           colour = "black",
           size = 1,
           linetype = "dashed",
@@ -209,7 +219,7 @@ testthat::test_that(
             ggplot2::expr("test" == "800")
           ),
           PANEL = structure(c(1L, 1L, 1L, 1L, 1L), class = "factor", .Label = "1"),
-          group = c(-1L, -1L, -1L, -1L, -1L),
+          group = structure(c(-1L, -1L, -1L, -1L, -1L), n = 1L),
           colour = c("black", "black", "black", "black", "black"),
           fill = c("white", "white", "white", "white", "white"),
           size = c(3, 3, 3, 3, 3),
@@ -232,7 +242,7 @@ testthat::test_that(
         list(
           xintercept = 852.4,
           PANEL = structure(1L, .Label = "1", class = "factor"),
-          group = -1L,
+          group = structure(c(-1L), n = 1L),
           colour = "blue",
           size = 1,
           linetype = "dashed",
@@ -257,7 +267,7 @@ testthat::test_that(
             ggplot2::expr("mean" == "852.40")
           ),
           PANEL = structure(c(1L, 1L, 1L, 1L, 1L), class = "factor", .Label = "1"),
-          group = c(-1L, -1L, -1L, -1L, -1L),
+          group = structure(c(-1L, -1L, -1L, -1L, -1L), n = 1L),
           colour = c("blue", "blue", "blue", "blue", "blue"),
           fill = c("white", "white", "white", "white", "white"),
           size = c(3, 3, 3, 3, 3),
